import 'package:flutter/material.dart';

enum FeedbackMessageType { error, info, success, warning }

class FeedbackMessage extends StatelessWidget {
  final IconData icon;
  final FeedbackMessageType type;
  final String shortMessage;
  final String longMessage;

  final Function action;
  final String actionTitle;
  final IconData actionIcon;

  const FeedbackMessage(
      {Key key,
      this.icon,
      this.shortMessage,
      this.longMessage,
      this.type,
      this.action,
      this.actionTitle,
      this.actionIcon})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.white,
      padding: EdgeInsets.fromLTRB(30, 30, 30, 80),
      child: Center(
          child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Icon(
            icon,
            size: 80,
            color: Color(0xFF00B8FF),
          ),
          Text(
            shortMessage,
            style: TextStyle(
                height: 1.6, fontSize: 24, fontWeight: FontWeight.w600),
          ),
          Text(
            longMessage,
            softWrap: true,
            textAlign: TextAlign.center,
            style: TextStyle(
                height: 1.4, fontSize: 18, fontWeight: FontWeight.w500),
          ),
          action != null
              ? Padding(
                  padding:
                      const EdgeInsets.symmetric(vertical: 20, horizontal: 30),
                  child: MaterialButton(
                      padding:
                          EdgeInsets.symmetric(horizontal: 16, vertical: 14.0),
                      color: Color(0xfff56a05),
                      child: Row(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          actionIcon != null
                              ? Icon(
                                  Icons.arrow_back,
                                  color: Colors.white,
                                  size: 22,
                                )
                              : Container(),
                          actionIcon != null
                              ? SizedBox(width: 10)
                              : Container(),
                          Flexible(
                            child: Text(
                              actionTitle,
                              overflow: TextOverflow.ellipsis,
                              style: TextStyle(
                                  fontSize: 18,
                                  color: Colors.white,
                                  fontWeight: FontWeight.w500),
                            ),
                          ),
                        ],
                      ),
                      shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(8)),
                      onPressed: action),
                )
              : Container()
        ],
      )),
    );
  }
}
