import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:medapay/entity.dart';
import 'package:medapay/src/screen/medapay_main.dart';
import 'package:medapay/src/service/medapay_service.dart';

class MedaPayLauncher {
  String _paymentTitle;
  String _authToken;
  bool _isSandbox;
  MedaPayService _medaPayService;

  MedaPayLauncher(
      {@required String paymentTitle,
      @required String authToken,
      @required bool isSandbox}) {
    this._paymentTitle = paymentTitle;
    this._authToken = authToken;
    this._isSandbox = isSandbox;

    _medaPayService = new MedaPayService(_isSandbox, _authToken);
  }

  void init(
      {@required BuildContext context,
      @required MedaPayPayment payment,
      @required Function onReferenceNumber,
      @required Function onSuccess,
      @required Function onCancel,
      @required Function onError,
      @required Function onBillInfo,
      List<String> paymentMethods = const [
        'amole',
        'cbebirr',
        'ebirr',
        'boa',
        'mbirr',
        'hellocash'
      ],
      String preferedPaymentMethod = ''}) {
    Navigator.push(
        context,
        MaterialPageRoute(
            builder: (context) => MedaPayMainScreen(
                paymentTitle: _paymentTitle,
                payment: payment,
                referenceNumber: 'n/a',
                service: _medaPayService,
                onReferenceNumber: onReferenceNumber,
                onCancel: onCancel,
                onSuccess: onSuccess,
                onError: onError,
                onBillInfo: onBillInfo,
                paymentMethods: paymentMethods,
                preferedPaymentMethod: preferedPaymentMethod)));
  }

  void initWithReferenceNumber(
      {@required BuildContext context,
      @required String referenceNumber,
      @required Function onSuccess,
      @required Function onCancel,
      @required Function onError,
      @required Function onBillInfo,
      List<String> paymentMethods = const [
        'amole',
        'cbebirr',
        'ebirr',
        'boa',
        'mbirr',
        'hellocash'
      ],
      String preferedPaymentMethod = ''}) {
    Navigator.push(
        context,
        MaterialPageRoute(
            builder: (context) => MedaPayMainScreen(
                paymentTitle: _paymentTitle,
                payment: MedaPayPayment(),
                referenceNumber: referenceNumber,
                service: _medaPayService,
                onReferenceNumber: () {}, //noop
                onCancel: onCancel,
                onSuccess: onSuccess,
                onError: onError,
                onBillInfo: onBillInfo,
                paymentMethods: paymentMethods,
                preferedPaymentMethod: preferedPaymentMethod)));
  }
}
