import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:medapay/src/components/preloader.dart';
import 'package:medapay/src/service/medapay_service.dart';
import 'package:webview_flutter/webview_flutter.dart';

class MedaPayAmoleScreen extends StatefulWidget {
  final MedaPayService service;
  final String referenceNumber;
  final Function onBillInfo;

  const MedaPayAmoleScreen(
      {Key key, this.service, this.referenceNumber, this.onBillInfo})
      : super(key: key);

  @override
  _MedaPayAmoleScreenState createState() => _MedaPayAmoleScreenState();
}

class _MedaPayAmoleScreenState extends State<MedaPayAmoleScreen> {
  bool isLoading = true;

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      child: Scaffold(
        appBar: AppBar(
          title: Image.asset(
              'packages/medapay/assets/images/medapay-appbar-logo.png',
              fit: BoxFit.cover),
          backgroundColor: Color(0xfff56a05),
          leading: Container(),
          centerTitle: true,
        ),
        body: Container(
            child: Stack(
          children: [
            WebView(
              javascriptMode: JavascriptMode.unrestricted,
              gestureNavigationEnabled: true,
              gestureRecognizers: <Factory<OneSequenceGestureRecognizer>>{
                Factory<VerticalDragGestureRecognizer>(
                  () => VerticalDragGestureRecognizer(),
                ),
              },
              onWebViewCreated: (WebViewController webViewController) {
                Map<String, String> headers = {
                  "Authorization": "Bearer " + widget.service.getAuthToken(),
                  "x-access-from": "mobile-app"
                };
                webViewController.loadUrl(
                    "${widget.service.getUrl()}dp/amole/${widget.referenceNumber}",
                    headers: headers);
              },
              onPageStarted: (url) {
                setState(() {
                  isLoading = true;
                });
              },
              onPageFinished: (url) {
                setState(() {
                  isLoading = false;
                });
              },
            ),
            isLoading
                ? Positioned(
                    top: 0,
                    bottom: 0,
                    right: 0,
                    left: 0,
                    child: Container(
                      color: Color(0x50FFFFFF),
                      child: Center(
                          child: Preloader(
                        title: "Loading",
                        subtitle: "Loading please wait...",
                      )),
                    ))
                : Container()
          ],
        )),
      ),
    );
  }
}
